/*
 * DemosceneMusic - BasePage.java - Copyright © 2012 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.demoscenemusic.page;

import net.pterodactylus.demoscenemusic.core.Core;
import net.pterodactylus.demoscenemusic.data.User;
import net.pterodactylus.util.template.Template;
import net.pterodactylus.util.template.TemplateContext;
import net.pterodactylus.util.template.TemplateContextFactory;
import net.pterodactylus.util.web.RedirectException;
import net.pterodactylus.util.web.TemplatePage;

/**
 * TODO
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class BasePage extends TemplatePage<ServletRequest> {

	private final Core core;

	/**
	 * @param path
	 * @param contentType
	 * @param templateContextFactory
	 * @param template
	 */
	public BasePage(Core core, TemplateContextFactory templateContextFactory, Template template, String pageName) {
		super(pageName, "text/html; charset=utf-8", templateContextFactory, template);
		this.core = core;
	}

	/**
	 * @return the core
	 */
	public Core getCore() {
		return core;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	protected void processTemplate(TemplateContext templateContext, ServletRequest request) throws RedirectException {
		super.processTemplate(templateContext, request);
		User currentUser = (User) request.getServletRequest().getSession().getAttribute("currentUser");
		templateContext.set("currentUser", currentUser);
		int requiredUserLevel = getRequiredUserLevel();
		if (((currentUser == null) && (requiredUserLevel > 0)) || ((currentUser != null) && (requiredUserLevel > currentUser.getLevel()))) {
			throw new RedirectException("login");
		}
	}

	/**
	 * Returns the {@link User#getLevel() user level} that is at least required
	 * to access the given page. If the returned level is {@code 0} (or
	 * smaller), users don’t have to be logged in.
	 *
	 * @return The lowest user level required to view this page
	 */
	protected int getRequiredUserLevel() {
		return 0;
	}

}
