/*
 * DemosceneMusic - RegisterPage.java - Copyright © 2012 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.demoscenemusic.page;

import java.util.List;

import net.pterodactylus.demoscenemusic.core.Core;
import net.pterodactylus.util.object.Default;
import net.pterodactylus.util.template.Template;
import net.pterodactylus.util.template.TemplateContext;
import net.pterodactylus.util.template.TemplateContextFactory;
import net.pterodactylus.util.web.Method;
import net.pterodactylus.util.web.RedirectException;

import org.openid4java.consumer.ConsumerException;
import org.openid4java.discovery.DiscoveryException;
import org.openid4java.discovery.DiscoveryInformation;
import org.openid4java.message.AuthRequest;
import org.openid4java.message.MessageException;

/**
 * TODO
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class RegisterPage extends BasePage {

	private static final String RETURN_URL = "http://www.demoscenemusic.org/openid";

	/**
	 * @param core
	 * @param templateContextFactory
	 * @param template
	 * @param pageName
	 */
	public RegisterPage(Core core, TemplateContextFactory templateContextFactory, Template template) {
		super(core, templateContextFactory, template, "register");
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	@SuppressWarnings("unchecked")
	protected void processTemplate(TemplateContext templateContext, ServletRequest request) throws RedirectException {
		super.processTemplate(templateContext, request);
		if (request.getMethod() == Method.POST) {
			String openId = Default.forNull(request.getServletRequest().getParameter("openid_url"), "").trim();
			templateContext.set("openid_url", openId);
			if ("".equals(openId)) {
				templateContext.set("error", "openid-empty");
				return;
			}
			try {
				List<DiscoveryInformation> discoveries = getCore().getConsumerManager().discover(openId);
				DiscoveryInformation discoveryInformation = getCore().getConsumerManager().associate(discoveries);
				request.getServletRequest().setAttribute("openid-discovery", discoveryInformation);
				AuthRequest authRequest = getCore().getConsumerManager().authenticate(discoveryInformation, RETURN_URL);
//				if (discoveryInformation.isVersion2()) {
//				} else {
				throw new RedirectException(authRequest.getDestinationUrl(true));
//				}
			} catch (DiscoveryException de1) {
				templateContext.set("error", "openid");
			} catch (MessageException me1) {
				me1.printStackTrace();
			} catch (ConsumerException ce1) {
				ce1.printStackTrace();
			}
		}
	}

}
